:mod:`joblib`.Parallel
=============================

.. currentmodule:: joblib

.. autoclass:: Parallel

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Parallel.__init__
      ~Parallel.debug
      ~Parallel.dispatch_next
      ~Parallel.dispatch_one_batch
      ~Parallel.format
      ~Parallel.print_progress
      ~Parallel.retrieve
      ~Parallel.warn
   
   

.. include:: joblib.Parallel.examples

.. raw:: html

    <div class="clearer"></div>